@@ -17,14 +17,14 @@ penalty <- function(t, v, d_net_lift){
   equal_rows <- (nrow(t)==nrow(v))
   same_rows <- FALSE
   if (equal_rows){
-     same_rows <- (!(any(t[[n]]==v[[n]])==FALSE))     
+     same_rows <- (!(any(t[["key"]]==v[["key"]])==FALSE))     
   }
   if (same_rows==FALSE){
     # make v look like t
-    v <- join(t[,c(n, "inside_train")], v, by=n, type="left")
+    v <- join(t[,c("inside_train", "key")], v, by="key", type="left")
     v[,sapply(v, is.numeric)] <- numcolwise(function(x) replace(x, is.na(x), 0))(v)
     # tag record that have validation buckets
-    t <- join(t, v[,c(n, "inside_valid")], by=n, type="left")
+    t <- join(t, v[,c("inside_valid", "key")], by="key", type="left")
     if (nrow(v)==0 | nrow(t)==0){
       t$PENALTY <- 0
     } else{
